import sys
import os

from .commands.help import help
from .commands.newnet import newnet
from .commands.fork import fork
from .commands.merge import merge
from .commands.login import login
from .commands.logout import logout
from .commands.server_init import server_init
from .commands.pull import pull
from .commands.push import push
from .commands.add import add
from .commands.commit import commit
from .commands.init import init

from .commands.constants import config_path

class ManageUtil:
    def __init__(self, argv=None):
        self.argv = argv or sys.argv[:]

    def execute(self):

        if len(self.argv) > 1:

            subcommand = self.argv[1]

            if subcommand == 'login':
                login()

            if subcommand == 'logout':
                logout()

            if subcommand == 'newnet':
                newnet()

            if subcommand == 'fork':
                fork()

            if subcommand == 'merge':
                merge()

            if subcommand == 'upload':
                server_init()

            if subcommand == 'push':
                push()

            if subcommand == 'pull':
                pull()

            if subcommand == 'add':
                add()

            if subcommand == 'commit':
                commit()

            if subcommand == 'init':
                init()

            if subcommand == '-h' or subcommand == '--help':
                help()

        else:
            help()


def execute_from_command_line(argv=None):
    util = ManageUtil(argv)
    util.execute()



def help():
    print('usage: nhm [-h] [login] [logout] [newnet] [fork] [merge]')
    print('\t [upload] [push] [pull] [add] [commit] [init]')
    print('\n')
    print('Nethub-Manager v.0.0.8')
    print('\n')
    print('optional arguments:')
    print('  -h, --help\t\t\t\t\tshow this message and exit')
    print('  login\t\t\t\t\t\tlogin to nethub-server')
    print('  logout\t\t\t\t\tlogout from nethub-server')
    print('  newnet <name_of_new_net> [-l, --local]\tcreate neural net project, remote or local')
    print('  fork <original_project> <new_project>\t\tfork local project')
    print('  merge <master_net> <second_net>\t\tmerge second net to master net')
    print('  upload\t\t\t\t\tupload local project to nethub-server')
    print('  push\t\t\t\t\t\tpush changes to nethub-server')
    print('  add\t\t\t\t\t\tstage changes')
    print('  commit\t\t\t\t\tcommit project changes')
    print('  init\t\t\t\t\t\tinitialization')
